@@ -23,8 +23,8 @@
 #include <QVector>
 #include <QString>
 #include <QObject>
-
-struct RenameCategory
+#include "libkdebugsettings_private_export.h"
+struct LIBKDEBUGSETTINGS_EXPORT_TEST_EXPORT RenameCategory
 {
 public:
     RenameCategory()
