@@ -22,8 +22,8 @@
 #define SAVERULESJOB_H
 
 #include "loggingcategory.h"
-
-class SaveRulesJob
+#include "libkdebugsettings_export.h"
+class LIBKDEBUGSETTINGS_EXPORT SaveRulesJob
 {
 public:
     SaveRulesJob();
@@ -36,6 +36,8 @@ public:
 
     Q_REQUIRED_RESULT bool start();
 
+    Q_REQUIRED_RESULT QString fileName() const;
+
 private:
     LoggingCategory::List mListKde;
     LoggingCategory::List mListCustom;
